<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Driver;
use App\Models\Load;
use App\Models\User;
use App\Models\Vendor;
use Carbon\Carbon;
use Laravel\Cashier\Subscription;
use Stripe\Charge;
use Stripe\Stripe;
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    public function index(){
        $data['companies']= User::role('company')->count();
        $data['loads']= Load::count();
        $data['drivers']= Driver::count();
        $data['vendors']= Vendor::count();
        $data['loads_array']= Load::latest()->take(10)->get();

        // Set the Stripe API key
        Stripe::setApiKey(config('cashier.secret'));

        // Retrieve all subscriptions
        $subscriptions = Subscription::all();

        // Calculate total earnings
        $totalEarnings = 0;
        $charges = Charge::all(['limit' => 100]); // Adjust the limit as needed
        foreach ($charges as $charge) {
            $totalEarnings += $charge->amount;
        }

        // Calculate current month earnings
        $currentMonthEarnings = 0;
        foreach ($charges as $charge) {
            $created = Carbon::createFromTimestamp($charge->created);
            if ($created->isCurrentMonth()) {
                $currentMonthEarnings += $charge->amount;
            }
        }

        // Prepare data for the graph (e.g., earnings per month for the last year)
        $monthlyEarnings = [];
        for ($i = 11; $i >= 0; $i--) {
            $startOfMonth = Carbon::now()->subMonths($i)->startOfMonth();
            $endOfMonth = Carbon::now()->subMonths($i)->endOfMonth();
            $monthlyEarning = 0;
            foreach ($charges as $charge) {
                $created = Carbon::createFromTimestamp($charge->created);
                if ($created->between($startOfMonth, $endOfMonth)) {
                    $monthlyEarning += $charge->amount;
                }
            }
            $monthlyEarnings[] = [
                'month' => $startOfMonth->format('F Y'),
                'earnings' => $monthlyEarning / 100 // Convert cents to dollars
            ];
        }

        return view('admin.dashboard.index', compact('data','totalEarnings', 'currentMonthEarnings', 'monthlyEarnings'));
    }
}
