<?php

namespace App\Http\Controllers\Api;

use App\Models\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Resources\UserResource;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;


class LoginRegisterController extends Controller
{
    
    public function login(Request $request){
        $validate = Validator::make($request->all(), [
            'email' => 'required|string|email',
            'password' => 'required|string|min:8',
        ]);

        if ($validate->fails()) {
            return response()->json([
                'status' => 'failed',
                'message' => 'Validation Error!',
                'data' => $validate->errors(),
            ], 403);
        }

        $user = User::where('email', $request->email)->first();
        if(!$user  || !Hash::check($request->password , $user->password)){
            return response()->json([
                'status' => 'failed',
                'message' => 'Invalid credentials'
            ], 401);
        }
        $data['token'] = $user->createToken($request->email)->plainTextToken;
        $response = [
            'status' => 'success',
            'message' => 'Driver is logged in successfully.',
            'data' => $data,
            'detail' => new UserResource($user) ,
        ];

        return response()->json($response, 200);

    }

    public function logout(Request $request){

        $user = auth()->user();
        if($user){
            $user->tokens()->delete();
            return response()->json([
                'status' => 'success',
                'message' => 'User is logged out successfully'
            ], 200);
        }

        return response([
            'message' => 'No authenticated user'
        ], 401);
    }


}
