<?php

namespace App\Http\Controllers;

use App\Models\Customer;
use Illuminate\Http\Request;

class CustomerController extends Controller
{
    protected $created_by;
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('partners.customers.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request);
        $request->validate([
            // 'image' => 'required',
            'name' => 'required',
            'address' => 'required',
            'address_line_2' => 'nullable',
            'phone' => 'required',
            'email' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'fid' => 'required',
            'mc' => 'required',
            'notes' => 'required',
            // 'broker_checkbox' => 'required|nullable',
            // 'shipper_checkbox' => 'required|nullable',
            'billing_type' => 'required',
            'fee' => 'required',
            'credit' => 'required',
            'avg_days' => 'required',
            'status' => 'required',
            'payterms' => 'required',
        ]);

        $data = $request->all();

        if ($request->hasFile('image')) {

            $data['image'] = storeFile($request->file('image'), 'storage/customer/');
        }

        $customers = Customer::create($data);
        return redirect()->route('partners.index')->with('success', 'Customer Created Successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $customer = Customer::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('partners.customers.create', compact('customer'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            // 'image' => 'required',
            'name' => 'required',
            'address' => 'required',
            'address_line_2' => 'nullable',
            'phone' => 'required',
            'email' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'fid' => 'required',
            'mc' => 'required',
            'notes' => 'required',
            // 'broker_checkbox' => 'required|nullable',
            // 'shipper_checkbox' => 'required|nullable',
            'billing_type' => 'required',
            'fee' => 'required',
            'credit' => 'required',
            'avg_days' => 'required',
            'status' => 'required',
            'payterms' => 'required',
        ]);

        $customer = Customer::where('created_by', $this->created_by)->where('id', $id)->first();
        $data = $request->all();
        if ($request->hasFile('image')) {
            // Delete the previous image
            $deletePath = "storage/customer/" . $customer->image;
            $deleteImage = deleteImage($deletePath);
            // Store the new image
            $data['image'] = storeFile(request('image'), 'storage/customer');
        }
        $customer->update($data);
        return redirect()->route('partners.customers.customer-details', $customer->id)->with('success', 'Customer Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $customer = Customer::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($customer) {
            $customer->delete();
            return redirect()->route('partners.index',)->with('success', 'Customer deleted successfully.');
        } else {
            return redirect()->route('partners.index',)->with('error', 'Record Not Found.');
        }
    }
}
