<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Expense;

class ExpenseController extends Controller
{
    protected $created_by;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $expenses = Expense::where('created_by', $this->created_by)->latest()->get();
        return view('expenses.index', compact('expenses'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {

        return view('expenses.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'date' => 'required',
            'payTo' => 'required',
            'amount' => 'required',
            'category' => 'required',
            'notes' => 'required',
        ]);
        Expense::create($request->all());
        return redirect()->route('expenses.index')->with('success', 'Expense created successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $expense = Expense::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('expenses.create', compact('expense'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'date' => 'required',
            'payTo' => 'required',
            'amount' => 'required',
            'category' => 'required',
            'notes' => 'required',
        ]);
        $expense = Expense::where('created_by', $this->created_by)->where('id', $id)->first();
        $expense->update($request->all());

        return redirect()->route('expenses.index')->with('success', 'Expense updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $expense = Expense::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($expense) {
            $expense->delete();
            return redirect()->route('expenses.index')->with('success', 'Expense deleted successfully');
        } else {
            return redirect()->route('expenses.index')->with('error', 'Record Not Found.');
        }
    }
}
