<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\FactoringReport;

class FactoringReportController extends Controller
{
    protected $created_by;
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    public function index()
    {
        $factoringReports = FactoringReport::where('created_by', $this->created_by)->latest()->get();
        return view('factoring-report.index', compact('factoringReports'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('factoring-report.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'partner' => 'required',
            'report_status' => 'required',
            'date' => 'required',
        ]);
        FactoringReport::create($request->all());
        return redirect()->route('factoring-reports.index')
            ->with('success', 'Factoring report created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $factoringReport = FactoringReport::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('factoring-report.create', compact('factoringReport'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'partner' => 'required',
            'report_status' => 'required',
            'date' => 'required',
        ]);
        $factoringReport = FactoringReport::where('created_by', $this->created_by)->where('id', $id)->first();
        $factoringReport->update($request->all());
        return redirect()->route('factoring-reports.index')
            ->with('success', 'Factoring report updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $factoringReport = FactoringReport::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($factoringReport) {
            $factoringReport->delete();
            return redirect()->route('factoring-reports.index')
                ->with('success', 'Factoring report deleted successfully.');
        } else {
            return redirect()->route('factoring-reports.index')
                ->with('error', 'Record Not Found.');
        }
    }
}
