<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Truck;
use App\Models\FuelCards;

class FuelCardController extends Controller
{

    protected $created_by;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $fuelCards = FuelCards::where('created_by',$this->created_by)->latest()->get();
        return view('fuel-card.index', compact('fuelCards'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $trucks = Truck::where('created_by',$this->created_by)->get();
        return view('fuel-card.create', compact('trucks'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'card_number' => 'required',
            'expiration_date' => 'required',
            'notes' => 'nullable',
        ]);
        $fuelCard = new FuelCards();
        $fuelCard->fill($request->all());
        $fuelCard->save();
        
        return redirect()->route('fuel-cards.index')->with('success', 'Fuel Card created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $trucks = Truck::where('created_by',$this->created_by)->get();
        $fuelCard = FuelCards::where('created_by',$this->created_by)->where('id',$id)->first();
        return view('fuel-card.create', compact('fuelCard','trucks'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'card_number' => 'required|string',
            'expiration_date' => 'required|string',
            'notes' => 'nullable|string',
        ]);
        $fuelCard = FuelCards::where('created_by',$this->created_by)->where('id',$id)->first();
        $fuelCard->update($request->all());

        return redirect()->route('fuel-cards.index')
            ->with('success', 'Fuel Card updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {

        $fuelCard = FuelCards::where('created_by',$this->created_by)->where('id',$id)->first();
        if($fuelCard){
            $fuelCard->delete();
            return redirect()->route('fuel-cards.index')->with('success', 'Fuel Card deleted successfully');
        }
        else{
            return redirect()->route('fuel-cards.index')->with('error', 'Record Not Found');

        }
        
    }
}
