<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\FuelTransaction;
use App\Models\Truck;
use App\Models\Trailer;
use App\Models\Driver;
use App\Models\FuelCards;

class FuelTransactionController extends Controller
{
    protected $created_by;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $fuelTransactions = FuelTransaction::where('created_by', $this->created_by)->latest()->get();
        return view('fuel-transaction.index', compact('fuelTransactions'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $trucks = Truck::where('created_by', $this->created_by)->get();
        $trailers = Trailer::where('created_by', $this->created_by)->get();
        $drivers = Driver::where('created_by', $this->created_by)->get();
        $fuelCards = FuelCards::where('created_by', $this->created_by)->get();
        return view('fuel-transaction.create', compact('trucks', 'trailers', 'drivers', 'fuelCards'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'equipment_owner' => 'required',
            'product_code' => 'required',
            'date' => 'required',
            'amount' => 'required',
            'units' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'notes' => 'nullable',
        ]);

        $fuelTransaction = new FuelTransaction();
        $fuelTransaction->fill($request->all());
        $fuelTransaction->save();
        return redirect()->route('fuel-transactions.index')->with('success', 'Fuel Transaction created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $trucks = Truck::where('created_by', $this->created_by)->get();
        $trailers = Trailer::where('created_by', $this->created_by)->get();
        $drivers = Driver::where('created_by', $this->created_by)->get();
        $fuelCards = FuelCards::where('created_by', $this->created_by)->get();
        $fuelTransaction = FuelTransaction::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('fuel-transaction.create', compact('trucks', 'trailers', 'drivers', 'fuelCards', 'fuelTransaction'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'equipment_owner' => 'required',
            'product_code' => 'required',
            'date' => 'required',
            'amount' => 'required',
            'units' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'notes' => 'nullable',
        ]);

        $fuelTransaction = FuelTransaction::where('created_by', $this->created_by)->where('id', $id)->first();
        $fuelTransaction->update($request->all());
        return redirect()->route('fuel-transactions.index')
            ->with('success', 'Fuel Transaction updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $fuelTransaction = FuelTransaction::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($fuelTransaction) {
            $fuelTransaction->delete();
            return redirect()->route('fuel-transactions.index')->with('success', 'Fuel Transaction deleted successfully');
        } else {
            return redirect()->route('fuel-transactions.index')->with('error', 'Record Not Found');
        }
    }
}
