<?php

namespace App\Http\Controllers;

use App\Models\Ifta;
use Illuminate\Http\Request;

class IftaController extends Controller
{
    protected $created_by;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $iftaReports = Ifta::where('created_by', $this->created_by)->latest()->get();
        return view('ifta.index', compact('iftaReports'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('ifta.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        Ifta::create($request->all());
        return redirect()->route('ifta.index')->with('success', 'IFTA Report created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $ifta = Ifta::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('ifta.create', compact('ifta'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $ifta = Ifta::where('created_by', $this->created_by)->where('id', $id)->first();
        $ifta->update($request->all());
        return redirect()->route('ifta.index')->with('success', 'IFTA report updated successfully.');
    }


    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $ifta = Ifta::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($ifta) {
            $ifta->delete();
            return redirect()->route('ifta.index')->with('success', 'IFTA record deleted successfully.');
        } else {
            return redirect()->route('ifta.index')->with('error', 'Record Not Found.');
        }
    }
}
