<?php

namespace App\Http\Controllers;

use Session;
use App\Models\Load;
use App\Models\User;
use App\Models\Truck;
use App\Models\Driver;
use App\Models\Trailer;
use Illuminate\Http\Request;

class LoadController extends Controller
{

    protected $created_by;
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    public function index()
    {
        $loads = Load::where('created_by', $this->created_by)->latest()->get();
        return view('loads.index', compact('loads'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $trucks = Truck::where('created_by', $this->created_by)->latest()->get();
        $trailers = Trailer::where('created_by', $this->created_by)->latest()->get();
        $drivers = User::role('driver')->whereHas('driver', function ($query) {
            $query->where('created_by', $this->created_by);
        })->latest()->get();
        return view('loads.create', compact('trucks', 'trailers', 'drivers'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'driver_id' => 'required',
            'trailer_id' => '',
            'truck_id' => '',
            'status' => 'required',
            'billing_status' => 'required',
            'dispatcher' => 'required',
            'pickup_date' => 'required',
            'pickup_city' => 'required',
            'pickup_state' => 'required',
            'pickup_zipcode' => 'required',
            'delivery_date' => 'required',
            'delivery_city' => 'required',
            'delivery_state' => 'required',
            'delivery_zipcode' => 'required',
            'broker_po' => 'required',
            'broker_state' => 'required',
            'broker_rate' => 'required',
            'notes' => 'required',
            'pick_up_address' => 'required',
            'pick_up_lat' => 'required',
            'pick_up_long' => 'required',
            'drop_Off_address' => 'required',
            'drop_Off_lat' => 'required',
            'drop_Off_long' => 'required',
            // 'attachment_url' => 'required|nullable'
        ]);

        $data = $request->all();
        if ($request->hasFile('attachment_url')) {
            $data['attachment_url'] = storeFile(request('attachment_url'), 'storage/loads/');
        }
        $loads = Load::create($data);

        return redirect()->route('loads.index')->with('success', 'Load Created Successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(Load $load)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $trucks = Truck::where('created_by', $this->created_by)->latest()->get();
        $trailers = Trailer::where('created_by', $this->created_by)->latest()->get();
        $drivers = User::role('driver')->whereHas('driver', function ($query) {
            $query->where('created_by', $this->created_by);
        })->latest()->get()
        ;
        $load = Load::where('created_by', $this->created_by)->where('id',$id)->first();
        return view('loads.create', compact('trucks', 'trailers', 'drivers', 'load'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'driver_id' => 'required',
            'trailer_id' => '',
            'truck_id' => '',
            'status' => 'required',
            'billing_status' => 'required',
            'dispatcher' => 'required',
            'pickup_date' => 'required',
            'pickup_city' => 'required',
            'pickup_state' => 'required',
            'pickup_zipcode' => 'required',
            'delivery_date' => 'required',
            'delivery_city' => 'required',
            'delivery_state' => 'required',
            'delivery_zipcode' => 'required',
            'broker_po' => 'required',
            'broker_state' => 'required',
            'broker_rate' => 'required',
            'notes' => 'required',
            'pick_up_address' => 'required',
            'pick_up_lat' => 'required',
            'pick_up_long' => 'required',
            'drop_Off_address' => 'required',
            'drop_Off_lat' => 'required',
            'drop_Off_long' => 'required',
            // 'attachment_url' => 'required|nullable'
        ]);

        $load = Load::where('created_by',$this->created_by)->where('id',$id)->first();
        $req_data = $request->all();
        if ($request->hasFile('attachment_url')) {
            $deletePath = "storage/loads/" . $load->attachment_url;
            $deleteImage  = deleteImage($deletePath);
            $req_data['attachment_url'] = storeFile(request('attachment_url'), 'storage/loads');
        }

        $load->update($req_data);
        return redirect()->route('loads.index')->with('success', 'Load Updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $load = Load::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($load) {
            $load->delete();
            return redirect()->route('loads.index')->with('success', 'Load deleted successfully.');
        } else {
            return redirect()->route('loads.index')->with('error', 'Record Not Found.');
        }
    }
}
