<?php

namespace App\Http\Controllers;

use App\Models\Payment;
use Illuminate\Http\Request;

class PaymentController extends Controller
{

    protected $created_by;
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $payments = Payment::where('created_by', $this->created_by)->latest()->get();
        return view('payment.index', compact('payments'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('payment.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request);
        $request->validate([
            'date' => 'required',
            'payee' => 'required',
            'payTo' => 'required',
            'type' => 'required',
            'amount' => 'required',
            'description' => 'required',
        ]);
        $payment = new Payment();
        $payment->fill($request->all());
        $payment->save();
        return redirect()->route('payments.index')->with('success', 'Payment inserted successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $payment = Payment::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('payment.create', compact('payment'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $payment = Payment::where('created_by', $this->created_by)->where('id', $id)->first();
        $payment->update($request->all());
        return redirect()->route('payments.index')->with('success', 'Payment updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $payment = Payment::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($payment) {
            $payment->delete();
            return redirect()->route('payments.index')->with('success', 'Payment deleted successfully.');
        } else {
            return redirect()->route('payments.index')->with('error', 'Record Not Found.');
        }
    }
}
