<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use App\Mail\SubscriptionInvoice;
use Illuminate\Support\Facades\Auth;
use Stripe\Stripe;
use Stripe\Price;

class PaymentSubscriptionController extends Controller
{
    public function index()
    {

        // get plans
        Stripe::setApiKey(config('cashier.secret'));
        $plans = Price::all();

        // get user seleted plan
        $user = Auth::user();
        $subscription = $user->subscription('default');

        // calculate 3 days
        $alert = '';
        if (isset($subscription->ends_at)) {
            $alertDate = $subscription->ends_at->copy()->subDays(3);
            $alert = Carbon::now()->greaterThanOrEqualTo($alertDate) && Carbon::now()->lessThanOrEqualTo($subscription->ends_at);
        }
        $invoices = $user->invoices();

        return view('subscription.payment-subscription', compact('plans', 'subscription', 'alert', 'invoices'));
    }
    public function showSubscriptionForm()
    {
        return view('subscription.subscription-form');
    }

    public function subscribe(Request $request)
    {
        $user = Auth::user();

        $paymentMethod = $request->payment_method;

        $plan = $request->plan;
        $stripePlanId = $plan === 'monthly' ? config('cashier.monthly') : config('cashier.yearly');

        $user->newSubscription('default', $stripePlanId)
            ->create($paymentMethod);
        // Retrieve the latest invoice
        $invoice = $user->invoices()->first();
        // Send the email with the invoice
        Mail::to($user->email)->send(new SubscriptionInvoice($invoice, $user));

        return redirect()->route('root')->with('success', 'Subscription successful!');
    }
    public function downloadInvoice($invoiceId)
    {
        $user = Auth::user();
        return $user->downloadInvoice($invoiceId, [
            'vendor' => config('app.name'),
            'product' => config('app.name') . ' Product',
        ]);
    }
}
