<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Trailer;

class TrailerController extends Controller
{
    protected $created_by;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $trailers = Trailer::where('created_by', $this->created_by)->latest()->get();
        return view('trailer.index', compact('trailers'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('trailer.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request);
        $request->validate([
            'unit' => 'required',
            'type' => 'required',
            'vin' => 'required',
            'year' => 'required',
            'make' => 'required',
            'model' => 'required',
            'driver' => 'required',
            'plate' => 'required',
            'plate_state' => 'required',
            'ownership_type' => 'required',
            'purchase_date' => 'required',
            'purchase_price' => 'required',
            'notes' => 'required',
            'history' => 'required',
        ]);

        $trailer = new Trailer();
        $trailer->fill($request->all());
        $trailer->save();

        return redirect()->route('trailers.index')->with('success', 'Trailer created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $trailer = Trailer::where('created_by', $this->created_by)->where('id', $id)->first();
        return view('trailers.show', compact('trailer'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $trailer = Trailer::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($trailer) {
            return view('trailer.create', compact('trailer'));
        } else {
            return redirect()->route('trailers.index')->with('error', 'Record Not Found.');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $trailer = Trailer::where('created_by', $this->created_by)->where('id', $id)->first();
        $trailer->update($request->all());
        return redirect()->route('trailers.index')->with('success', 'Trailer updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $trailer = Trailer::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($trailer) {
            $trailer->delete();
            return redirect()->route('trailers.index')->with('success', 'Trailer deleted successfully.');
        } else {
            return redirect()->route('trailers.index')->with('error', 'Record Not Found.');
        }
    }
}
