<?php

namespace App\Http\Controllers;

use App\Models\Truck;
use Illuminate\Http\Request;

class TruckController extends Controller
{
    protected $created_by;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $trucks = Truck::where('created_by', $this->created_by)->latest()->get();
        return view('truck.index', compact('trucks'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('truck.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request);
        $request->validate([
            'unit' => 'required',
            'vin' => 'required',
            'eld_provider' => 'required',
            'eld_id' => 'required',
            'year' => 'required',
            'make' => 'required',
            'model' => 'required',
            'ownership' => 'required',
            'driver' => 'required',
            'plate' => 'required',
            'plate_state' => 'required',
            'purchase_date' => 'required',
            'purchase_price' => 'required',
            'notes' => 'required',
            'history' => 'required'
        ]);
        $truck = new Truck();
        $truck->fill($request->all());
        $truck->save();

        return redirect()->route('trucks.index')->with('success', 'Truck created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $truck = Truck::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($truck) {
            return view('truck.create', compact('truck'));
        } else {
            return redirect()->route('trucks.index')->with('error', 'Record not found');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'unit' => 'required',
            'vin' => 'required',
            'eld_provider' => 'required',
            'eld_id' => 'required',
            'year' => 'required',
            'make' => 'required',
            'model' => 'required',
            'ownership' => 'required',
            'driver' => 'required',
            'plate' => 'required',
            'plate_state' => 'required',
            'purchase_date' => 'required',
            'purchase_price' => 'required',
            'notes' => 'required',
            'history' => 'required'
        ]);
        $truck = Truck::where('created_by', $this->created_by)->where('id', $id)->first();;
        $truck->fill($request->all());
        $truck->save();
        return redirect()->route('trucks.index')->with('success', 'Truck updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $truck = Truck::where('created_by', $this->created_by)->where('id', $id)->first();
        if ($truck) {
            $truck->delete();
            return redirect()->route('trucks.index')->with('success', 'Truck deleted successfully.');
        } else {
            return redirect()->route('trucks.index')->with('erroe', 'Record not found.');
        }
    }
}
