<?php

namespace App\Http\Controllers;

use App\Models\Vendor;
use Illuminate\Http\Request;

class VendorController extends Controller
{
    protected $created_by;
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->created_by = auth()->user()->id;
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('partners.vendors.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // dd($request);
        $request->validate([
            // 'image' => 'required',
            'name' => 'required',
            'address' => 'required',
            'address_line_2' => 'nullable',
            'phone' => 'required',
            'email' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'fid' => 'required',
            'mc' => 'required',
            'notes' => 'required',
        ]);

        $data = $request->all();

        if ($request->hasFile('image')) {
            $data['image'] = storeFile($request->file('image'), 'storage/vendor/');
        }

        $vendors = Vendor::create($data);
        return redirect()->route('partners.index')->with('success', 'Vendor Created Successfully');

    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $vendor = Vendor::where('created_by',$this->created_by)->where('id',$id)->first();
        return view('partners.vendors.create', compact('vendor'));

    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            // 'image' => 'required',
            'name' => 'required',
            'address' => 'required',
            'address_line_2' => 'nullable',
            'phone' => 'required',
            'email' => 'required',
            'city' => 'required',
            'state' => 'required',
            'zipcode' => 'required',
            'fid' => 'required',
            'mc' => 'required',
            'notes' => 'required',
        ]);

        $vendor = Vendor::where('created_by',$this->created_by)->where('id',$id)->first();
        $data = $request->all();
        if ($request->hasFile('image')) {
            // Delete the previous image
            $deletePath = "storage/vendor/" . $vendor->image;
            $deleteImage = deleteImage($deletePath);
            // Store the new image
            $data['image'] = storeFile(request('image'), 'storage/vendor');
        }

        $vendor->update($data);
        return redirect()->route('partners.vendors.vendor-details', $vendor->id)->with('success', 'Vendor Updated Successfully');

    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $vendor = Vendor::where('created_by',$this->created_by)->where('id',$id)->first();
        if($vendor){
            $vendor->delete();
            return redirect()->route('partners.index')->with('success', 'Vendor deleted successfully.');
        }
        else{
            return redirect()->route('partners.index')->with('error', 'Record Not Found.');

        }
        

    }
}
