<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class CheckSubscription
{
    /**
     * Handle an incoming request.
     *
     * @param  \Closure(\Illuminate\Http\Request): (\Symfony\Component\HttpFoundation\Response)  $next
     */
    public function handle(Request $request, Closure $next)
    {
        $user = Auth::user();

        // Check if the user is authenticated
        if ($user) {
            $subscription = $user->subscription('default');

            // If the user has no subscription, redirect to the subscription page
            if (!$subscription) {
                return redirect()->route('plans.list')->with('info', 'Please select a plan to continue.');
            }

            // If the user's subscription has ended or is in a grace period
            if ($subscription->ended() || $subscription->onGracePeriod()) {
                return redirect()->route('plans.list')->with('info', 'Your plan has ended. Please select a new plan.');
            }
        }

        return $next($request);
    }
}
