<?php

namespace App\Traits;

use App\Models\User;
use Illuminate\Support\Facades\Auth;

trait CreatedBy
{
    /**
     * Boot the CreatedByTrait for a model.
     *
     * @return void
     */
    public static function bootCreatedBy()
    {
        static::creating(function ($model) {
            $model->created_by = Auth::id();
        });
    }

    public function scopeCreatedBy($query, $userId)
    {
        return $query->where('created_by', $userId);
    }

    /**
     * Get the user who created the record.
     */
    public function creator()
    {
        return $this->belongsTo(User::class, 'created_by');
    }

}