@extends('layouts.master')

@section('title')
    @lang('translation.payment-subscription')
@endsection

@section('content')
    <div class="container">
        <section class="section bg-light pt-5 rounded-4" id="plans">
            <div class="bg-overlay bg-overlay-pattern"></div>
            <div class="container">
                @if ($alert)
                    <div class="alert alert-warning alert-dismissible fade show" role="alert">
                        Your subscription is expiring in less than 3 days. Please renew your subscription to continue using the service.
                        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                    </div>
                @endif
                @if ($subscription)
                    <h2>Your Current Plan Details</h2>
                    @if($subscription->stripe_price== config('cashier.monthly'))
                        <p>Plan: Monthly</p>
                    @endif
                    @if($subscription->stripe_price== config('cashier.yearly'))
                        <p>Plan: Yearly</p>
                    @endif
                    <p>Start Date: {{ $subscription->created_at->toFormattedDateString() }}</p>
                    <p>End Date: {{ $subscription->ends_at ? $subscription->ends_at->toFormattedDateString() : 'N/A' }}</p>
                    <p>Status: {{ $subscription->active() ? 'Active' : 'Inactive' }}</p>

                    <div class="card">
                        <div class="card-header align-items-center d-flex">
                            <h4 class="card-title mb-0 flex-grow-1">Invoices</h4>
                        </div>
                        <div class="card-body">
                            <div class="table-responsive table-card">
                                <table class="table table-borderless table-centered align-middle table-nowrap mb-0">
                                    <thead class="text-muted table-light">
                                        <tr>
                                            <th scope="col">#Invoice Number</th>
                                            <th scope="col">Date</th>
                                            <th scope="col">Total</th>
                                            <th scope="col">Download</th>

                                        </tr>
                                    </thead>
                                    <tbody>
                                        @foreach ($invoices as $key=> $invoice)
                                        <tr>
                                            <td>{{$invoice->number}} </td>
                                            <td>{{ $invoice->date()->toFormattedDateString() }}</td>
                                            <td>
                                                <span class="text-success">{{ $invoice->total() }}</span>
                                            </td>
                                            <td>
                                                <a href="{{ route('invoice.download', $invoice->id) }}" class="fw-medium link-primary">Download</a>
                                            </td>
                                        </tr><!-- end tr -->
                                        @endforeach
                                    </tbody><!-- end tbody -->
                                </table><!-- end table -->
                            </div>
                        </div>
                    </div>
                @else
                    <div class="row justify-content-center">
                        <div class="col-lg-8">
                            <div class="text-center ">
                                <h3 class="mb-3 fw-semibold">Choose the plan that's right for you</h3>
                                <p class="text-muted mb-4">Simple pricing. No hidden fees. Advanced features for you
                                    business.</p>
                            </div>
                        </div>
                        <!-- end col -->
                    </div>
                    <!-- end row -->

                    <div class="row gy-4 justify-content-center">
                        @foreach ($plans as $item)
                            <div class="col-lg-4">
                                <div class="card plan-box mb-0 h-100">
                                    <div class="card-body p-4 m-2">
                                        <div class="d-flex align-items-center">
                                            <div class="flex-grow-1">
                                                <h5 class="mb-1 fw-semibold text-capitalize">
                                                    {{ $item->recurring->interval }}</h5>
                                                {{-- <p class="text-muted mb-0">For Startup</p> --}}
                                            </div>
                                            <div class="avatar-sm">
                                                <div class="avatar-title bg-light rounded-circle text-primary">
                                                    <i class="ri-book-mark-line fs-20"></i>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="py-4 text-center">
                                            <h1 class="month">
                                                <sup><small>{{ strtoupper($item->currency) }}</small></sup><span
                                                    class="ff-secondary fw-bold">{{ number_format($item->unit_amount / 100, 2) }}</span>
                                                <span class="fs-13 text-muted">/{{ $item->recurring->interval }}</span></h1>
                                            {{-- <h1 class="annual"><sup><small>$</small></sup><span
                                        class="ff-secondary fw-bold">171</span> <span
                                        class="fs-13 text-muted">/Year</span></h1> --}}
                                        </div>

                                        <div>
                                            <ul class="list-unstyled text-muted vstack gap-3 ff-secondary">
                                                @if (isset($item->metadata))
                                                    @php
                                                        $plan_features = $item->metadata->toArray();
                                                    @endphp
                                                    @foreach ($plan_features as $key => $plan_feature)
                                                        <li>
                                                            <div class="d-flex">
                                                                <div class="flex-shrink-0 text-success me-1">
                                                                    <i
                                                                        class="ri-checkbox-circle-fill fs-15 align-middle"></i>
                                                                </div>
                                                                <div class="flex-grow-1">
                                                                    {{ $key }}: {{ $plan_feature }}
                                                                </div>
                                                            </div>
                                                        </li>
                                                    @endforeach
                                                @endif

                                            </ul>
                                            <div class="mt-4">
                                                <a href="{{ route('subscribe.form', ['plan' => $item->recurring->interval]) }}"
                                                    class="btn btn-soft-success w-100">Get Started</a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        @endforeach
                        <!--end col-->
                    </div>
                    <!--end row-->
                @endif
            </div>
            <!-- end container -->
        </section>
    </div>
@endsection
