@extends('layouts.master')
@section('title')
    Subscribe
@endsection
@section('css')
    <link href="{{ URL::asset('build/libs/swiper/swiper-bundle.min.css') }}" rel="stylesheet" type="text/css" />
    <style>
        .StripeElement {
            box-sizing: border-box;
            width: 50%;
            height: 40px;
            padding: 10px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            background-color: white;
            box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }
        .StripeElement--focus {
            border-color: #80bdff;
            box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
        }
        .StripeElement--invalid {
            border-color: #e3342f;
        }
        .StripeElement--webkit-autofill {
            background-color: #fefde5 !important;
        }

        /* Custom styles for the subscribe button */
        .btn-subscribe {
            display: inline-block;
            font-weight: 400;
            color: #fff;
            background-color: #007bff;
            border-color: #007bff;
            text-align: center;
            vertical-align: middle;
            cursor: pointer;
            border: 1px solid transparent;
            padding: 0.375rem 0.75rem;
            font-size: 1rem;
            line-height: 1.5;
            border-radius: 0.25rem;
            transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        }
        .btn-subscribe:hover {
            color: #fff;
            background-color: #0056b3;
            border-color: #004085;
        }
        .btn-subscribe:focus {
            outline: 0;
            box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5);
        }
        .btn-subscribe:disabled {
            opacity: 0.65;
        }
    </style>
@endsection
@section('body')
    <body data-bs-spy="scroll" data-bs-target="#navbar-example">
@endsection
@section('content')
<h1>Choose a Plan</h1>
<form id="payment-form" action="{{ route('subscribe') }}" method="POST">
    @csrf
    <label>
        <input type="radio" name="plan" value="monthly" {{request()->get('plan')=="month"? "checked":'checked'}} > Monthly Plan
    </label>
    <label>
        <input type="radio" name="plan" value="yearly"  {{request()->get('plan')=="year"? "checked":''}}> Yearly Plan
    </label>

    <div class="pb-3">
        <img src="{{asset('build/images/banks.png')}}" alt="">
    </div>
    <div id="card-element"><!--Stripe.js injects the Card Element--></div>
       <button class="btn-subscribe button-css btn btn-primary mt-3" type="submit">Subscribe</button>
</form>
@endsection
@section('script')
     <script src="https://js.stripe.com/v3/"></script>

    <script src="{{ URL::asset('build/libs/swiper/swiper-bundle.min.js') }}"></script>
    <script src="{{ URL::asset('build/js/pages/landing.init.js') }}"></script>

    <script>

        var stripe = Stripe("{{config('cashier.key')}}");
        var elements = stripe.elements();
        var cardElement = elements.create('card', {
            style: {
                base: {
                    color: '#32325d',
                    fontFamily: '"Helvetica Neue", Helvetica, sans-serif',
                    fontSmoothing: 'antialiased',
                    fontSize: '16px',
                    '::placeholder': {
                        color: '#aab7c4'
                    }
                },
                invalid: {
                    color: '#fa755a',
                    iconColor: '#fa755a'
                }
            }
        });
        cardElement.mount('#card-element');

        var form = document.getElementById('payment-form');
        form.addEventListener('submit', async function(event) {
            event.preventDefault();

            const { paymentMethod, error } = await stripe.createPaymentMethod(
                'card', cardElement, {
                    billing_details: { name: '{{ Auth::user()->name }}' }
                }
            );

            if (error) {
                console.error(error);
            } else {
                var hiddenInput = document.createElement('input');
                hiddenInput.setAttribute('type', 'hidden');
                hiddenInput.setAttribute('name', 'payment_method');
                hiddenInput.setAttribute('value', paymentMethod.id);
                form.appendChild(hiddenInput);

                form.submit();
            }
        });
    </script>
@endsection
