<?php

use App\Http\Controllers\PaymentSubscriptionController;
use App\Http\Controllers\Site\SubscriptionController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Route::get('/', [App\Http\Controllers\Site\SiteController::class, 'welcome'])->name('welcome');
Auth::routes();

//Language Translation
Route::get('index/{locale}', [App\Http\Controllers\HomeController::class, 'lang']);
Route::group(['middleware' => 'auth'], function () {
    Route::get('/subscribe', [PaymentSubscriptionController::class, 'showSubscriptionForm'])->name('subscribe.form');
    Route::post('/subscribe', [PaymentSubscriptionController::class, 'subscribe'])->name('subscribe');
    Route::get('/choose-plane', [PaymentSubscriptionController::class, 'index'])->name('plans.list');
    //Update User Details
    Route::get('profile', [App\Http\Controllers\HomeController::class, 'profile'])->name('user.profile');
    Route::post('/update-profile/{id}', [App\Http\Controllers\HomeController::class, 'updateProfile'])->name('updateProfile');
    Route::post('/update-password/{id}', [App\Http\Controllers\HomeController::class, 'updatePassword'])->name('updatePassword');
    Route::middleware(['subscription'])->group(function () {
        Route::get('/home', [App\Http\Controllers\HomeController::class, 'root'])->name('root');
        Route::resource('trucks', 'App\Http\Controllers\TruckController');
        Route::resource('trailers', 'App\Http\Controllers\TrailerController');
        Route::resource('drivers', 'App\Http\Controllers\DriverController');
        Route::resource('fuel-cards', 'App\Http\Controllers\FuelCardController');
        Route::resource('fuel-transactions', 'App\Http\Controllers\FuelTransactionController');
        Route::resource('important-templates', 'App\Http\Controllers\ImportantTemplateController');
        Route::resource('loads', 'App\Http\Controllers\LoadController');
        Route::resource('important-templates', 'App\Http\Controllers\ImportantTemplateController');
        Route::resource('driver-payroll', 'App\Http\Controllers\DriverPayrollController');
        Route::resource('payments', 'App\Http\Controllers\PaymentController');
        Route::resource('expenses', 'App\Http\Controllers\ExpenseController');
        Route::resource('factoring-reports', 'App\Http\Controllers\FactoringReportController');
        Route::resource('ifta', 'App\Http\Controllers\IftaController');
        Route::resource('settings', 'App\Http\Controllers\SettingController');
        Route::get('/partners', 'App\Http\Controllers\PartnerController@index')->name('partners.index');
        Route::get('/customer-details/{id}', 'App\Http\Controllers\CustomerDetailsController@show')->name('partners.customers.customer-details');
        Route::get('/vendor-details/{id}', 'App\Http\Controllers\VendorDetailsController@show')->name('partners.vendors.vendor-details');
        Route::get('/dispatch-board', 'App\Http\Controllers\DispatchBoardController@index');
        Route::resource('customers', 'App\Http\Controllers\CustomerController');
        Route::resource('vendors', 'App\Http\Controllers\VendorController');

        Route::get('/invoice/{invoiceId}', [PaymentSubscriptionController::class, 'downloadInvoice'])->name('invoice.download');

    });
    // admin routes
    Route::resource('companies', 'App\Http\Controllers\Admin\CompanyController');
    Route::get('subscription-payment-list', [App\Http\Controllers\Admin\SubscriptionController::class, 'index'])->name('subscription.payment.list');
    Route::get('dashboard-overview', [App\Http\Controllers\Admin\DashboardController::class, 'index'])->name('dashboard.overview');
});
